"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.users.users_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SettingsUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> prodvana.proto.prodvana.users.users_pb2.User: ...
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        user: prodvana.proto.prodvana.users.users_pb2.User | None = ...,
        roles: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["roles", b"roles", "user", b"user"]) -> None: ...

global___SettingsUser = SettingsUser

class GetUserReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_id", b"user_id"]) -> None: ...

global___GetUserReq = GetUserReq

class GetUserResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___SettingsUser: ...
    def __init__(
        self,
        *,
        user: global___SettingsUser | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user", b"user"]) -> None: ...

global___GetUserResp = GetUserResp

class ListRolesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListRolesReq = ListRolesReq

class RoleDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    description: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name"]) -> None: ...

global___RoleDefinition = RoleDefinition

class ListRolesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLES_FIELD_NUMBER: builtins.int
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoleDefinition]: ...
    def __init__(
        self,
        *,
        roles: collections.abc.Iterable[global___RoleDefinition] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["roles", b"roles"]) -> None: ...

global___ListRolesResp = ListRolesResp

class ListUsersReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListUsersReq = ListUsersReq

class ListUsersResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SettingsUser]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        users: collections.abc.Iterable[global___SettingsUser] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "users", b"users"]) -> None: ...

global___ListUsersResp = ListUsersResp

class SetRolesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        roles: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["roles", b"roles", "user_id", b"user_id"]) -> None: ...

global___SetRolesReq = SetRolesReq

class SetRolesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetRolesResp = SetRolesResp

class UserInvite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAIL_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    email: builtins.str
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        email: builtins.str = ...,
        roles: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email", b"email", "roles", b"roles"]) -> None: ...

global___UserInvite = UserInvite

class InviteUsersReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserInvite]: ...
    def __init__(
        self,
        *,
        users: collections.abc.Iterable[global___UserInvite] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["users", b"users"]) -> None: ...

global___InviteUsersReq = InviteUsersReq

class InviteUsersResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___InviteUsersResp = InviteUsersResp

class OrganizationSupportsInvitesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___OrganizationSupportsInvitesReq = OrganizationSupportsInvitesReq

class OrganizationSupportsInvitesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUPPORTS_INVITES_FIELD_NUMBER: builtins.int
    supports_invites: builtins.bool
    def __init__(
        self,
        *,
        supports_invites: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["supports_invites", b"supports_invites"]) -> None: ...

global___OrganizationSupportsInvitesResp = OrganizationSupportsInvitesResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.release_channel.release_channel_manager_pb2

class ReleaseChannelManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ConfigureReleaseChannel: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ConfigureReleaseChannelReq,
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ConfigureReleaseChannelResp,
    ]
    ListReleaseChannels: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ListReleaseChannelsReq,
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ListReleaseChannelsResp,
    ]
    DeleteReleaseChannel: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.DeleteReleaseChannelReq,
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.DeleteReleaseChannelResp,
    ]
    ListReleaseChannelsV2: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ListReleaseChannelsReq,
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ListReleaseChannelsResp,
    ]
    """identical to ListReleaseChannels, kept for backwards compatibility"""
    GetReleaseChannel: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelReq,
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelResp,
    ]
    GetReleaseChannelConfig: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelConfigReq,
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelConfigResp,
    ]
    GetReleaseChannelEvents: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelEventsReq,
        prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelEventsResp,
    ]

class ReleaseChannelManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ConfigureReleaseChannel(
        self,
        request: prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ConfigureReleaseChannelReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ConfigureReleaseChannelResp: ...
    @abc.abstractmethod
    def ListReleaseChannels(
        self,
        request: prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ListReleaseChannelsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ListReleaseChannelsResp: ...
    @abc.abstractmethod
    def DeleteReleaseChannel(
        self,
        request: prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.DeleteReleaseChannelReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.DeleteReleaseChannelResp: ...
    @abc.abstractmethod
    def ListReleaseChannelsV2(
        self,
        request: prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ListReleaseChannelsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.ListReleaseChannelsResp:
        """identical to ListReleaseChannels, kept for backwards compatibility"""
    @abc.abstractmethod
    def GetReleaseChannel(
        self,
        request: prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelResp: ...
    @abc.abstractmethod
    def GetReleaseChannelConfig(
        self,
        request: prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelConfigReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelConfigResp: ...
    @abc.abstractmethod
    def GetReleaseChannelEvents(
        self,
        request: prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelEventsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.release_channel.release_channel_manager_pb2.GetReleaseChannelEventsResp: ...

def add_ReleaseChannelManagerServicer_to_server(servicer: ReleaseChannelManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.common_config.meta_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PipelineRunState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TERMINAL_FIELD_NUMBER: builtins.int
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    state: builtins.str
    terminal: builtins.bool
    """if pipeline run is in a terminal state"""
    def __init__(
        self,
        *,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        state: builtins.str = ...,
        terminal: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "last_update_timestamp", b"last_update_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "last_update_timestamp", b"last_update_timestamp", "state", b"state", "terminal", b"terminal"]) -> None: ...

global___PipelineRunState = PipelineRunState

class PipelineRun(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.common_config.meta_pb2.PipelineRunObjectMeta: ...
    @property
    def state(self) -> global___PipelineRunState: ...
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.common_config.meta_pb2.PipelineRunObjectMeta | None = ...,
        state: global___PipelineRunState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["meta", b"meta", "state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["meta", b"meta", "state", b"state"]) -> None: ...

global___PipelineRun = PipelineRun



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/metrics/metrics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprodvana/metrics/metrics.proto\x12\x10prodvana.metrics\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x08\n\x11\x44\x65ploymentMetrics\x12:\n\x06values\x18\x01 \x01(\x0b\x32*.prodvana.metrics.DeploymentMetrics.Values\x12I\n\ntimeseries\x18\x02 \x03(\x0b\x32\x35.prodvana.metrics.DeploymentMetrics.TimeseriesMetrics\x12:\n\x06\x64\x65ltas\x18\x03 \x01(\x0b\x32*.prodvana.metrics.DeploymentMetrics.Deltas\x1a\xbb\x02\n\x06\x44\x65ltas\x12\x19\n\x11total_deployments\x18\x01 \x01(\x01\x12\x1e\n\x16successful_deployments\x18\x02 \x01(\x01\x12&\n\x1esuccessful_deployments_per_day\x18\x03 \x01(\x01\x12\x1a\n\x12\x66\x61iled_deployments\x18\x04 \x01(\x01\x12-\n%median_successful_deployment_duration\x18\x05 \x01(\x01\x12\x1f\n\x17\x64\x65ployment_failure_rate\x18\x06 \x01(\x01\x12\x17\n\x0ftotal_rollbacks\x18\x07 \x01(\x01\x12\x1c\n\x14successful_rollbacks\x18\x08 \x01(\x01\x12+\n#median_successful_rollback_duration\x18\t \x01(\x01\x1a\xc1\x03\n\x06Values\x12\x19\n\x11total_deployments\x18\x01 \x01(\x01\x12\x1e\n\x16successful_deployments\x18\x02 \x01(\x01\x12&\n\x1esuccessful_deployments_per_day\x18\x03 \x01(\x01\x12\x1a\n\x12\x66\x61iled_deployments\x18\x04 \x01(\x01\x12H\n%median_successful_deployment_duration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1f\n\x17\x64\x65ployment_failure_rate\x18\x06 \x01(\x01\x12\x17\n\x0ftotal_rollbacks\x18\x07 \x01(\x01\x12\x1c\n\x14successful_rollbacks\x18\x08 \x01(\x01\x12\x46\n#median_successful_rollback_duration\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12N\n*last_successful_deployment_completion_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a~\n\x11TimeseriesMetrics\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x16successful_deployments\x18\x02 \x01(\x01\x12\x1a\n\x12\x66\x61iled_deployments\x18\x03 \x01(\x01\"(\n\x04\x43ost\x12\x12\n\nconfigured\x18\x01 \x01(\x08\x12\x0c\n\x04\x63ost\x18\x02 \x01(\x02\x42LZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/metricsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.metrics.metrics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/metrics'
  _globals['_DEPLOYMENTMETRICS']._serialized_start=118
  _globals['_DEPLOYMENTMETRICS']._serialized_end=1230
  _globals['_DEPLOYMENTMETRICS_DELTAS']._serialized_start=335
  _globals['_DEPLOYMENTMETRICS_DELTAS']._serialized_end=650
  _globals['_DEPLOYMENTMETRICS_VALUES']._serialized_start=653
  _globals['_DEPLOYMENTMETRICS_VALUES']._serialized_end=1102
  _globals['_DEPLOYMENTMETRICS_TIMESERIESMETRICS']._serialized_start=1104
  _globals['_DEPLOYMENTMETRICS_TIMESERIESMETRICS']._serialized_end=1230
  _globals['_COST']._serialized_start=1232
  _globals['_COST']._serialized_end=1272
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.repo import repo_pb2 as prodvana_dot_repo_dot_repo__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprodvana/release/object.proto\x12\x10prodvana.release\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1aprodvana/object/meta.proto\x1a\x18prodvana/repo/repo.proto\x1a\x17validate/validate.proto\"\xfa\x01\n\rReleaseConfig\x12\x36\n\x12\x63reation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\"\n\x11\x64\x65ployment_system\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x0b\x61pplication\x18\x08 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\nrepository\x18\x05 \x01(\t\x12\x11\n\tcommit_id\x18\x06 \x01(\t\x12\x0c\n\x04user\x18\x07 \x01(\t\"z\n\x0cReleaseState\x12/\n\x06status\x18\x01 \x01(\x0e\x32\x1f.prodvana.release.ReleaseStatus\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"g\n\x18ImpactAnalysisComparison\x12/\n\x10relevant_commits\x18\x01 \x03(\x0b\x32\x15.prodvana.repo.Commit\x12\x1a\n\x12unanalyzed_commits\x18\x02 \x01(\x03\"\x97\x02\n\x11ReleaseComparison\x12)\n\x04prev\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x17\n\x0fprev_repository\x18\x02 \x01(\t\x12\x16\n\x0enew_repository\x18\x03 \x01(\t\x12\x16\n\x0eprev_commit_id\x18\x04 \x01(\t\x12\x15\n\rnew_commit_id\x18\x05 \x01(\t\x12\x43\n\x0fimpact_analysis\x18\x06 \x01(\x0b\x32*.prodvana.release.ImpactAnalysisComparison\x12\x32\n\rtotal_commits\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xcd\x01\n\x07Release\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12/\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1f.prodvana.release.ReleaseConfig\x12\x37\n\ncomparison\x18\x03 \x01(\x0b\x32#.prodvana.release.ReleaseComparison\x12-\n\x05state\x18\x04 \x01(\x0b\x32\x1e.prodvana.release.ReleaseState*K\n\rReleaseStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tSUCCEEDED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x42LZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/releaseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.release.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release'
  _RELEASECONFIG.fields_by_name['deployment_system']._options = None
  _RELEASECONFIG.fields_by_name['deployment_system']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECONFIG.fields_by_name['service']._options = None
  _RELEASECONFIG.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECONFIG.fields_by_name['release_channel']._options = None
  _RELEASECONFIG.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECONFIG.fields_by_name['application']._options = None
  _RELEASECONFIG.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RELEASESTATUS']._serialized_start=1167
  _globals['_RELEASESTATUS']._serialized_end=1242
  _globals['_RELEASECONFIG']._serialized_start=196
  _globals['_RELEASECONFIG']._serialized_end=446
  _globals['_RELEASESTATE']._serialized_start=448
  _globals['_RELEASESTATE']._serialized_end=570
  _globals['_IMPACTANALYSISCOMPARISON']._serialized_start=572
  _globals['_IMPACTANALYSISCOMPARISON']._serialized_end=675
  _globals['_RELEASECOMPARISON']._serialized_start=678
  _globals['_RELEASECOMPARISON']._serialized_end=957
  _globals['_RELEASE']._serialized_start=960
  _globals['_RELEASE']._serialized_end=1165
# @@protoc_insertion_point(module_scope)



from collections.abc import Set
from typing import NamedTuple

from prodvana.client import Client
from prodvana.proto.prodvana.desired_state import manager_pb2
from prodvana.proto.prodvana.service import service_manager_pb2


class TagDetails(NamedTuple):
    tag: str
    repository: str | None
    registry_name: str | None
    registry_id: str | None


class ImageDetails(NamedTuple):
    image_url: str | None = None
    tag: TagDetails | None = None


def get_target_images_for_desired_state(
    client: Client, summary: manager_pb2.DesiredStateSummary
) -> Set[ImageDetails]:
    class ServiceVersion(NamedTuple):
        application: str
        service: str
        version: str

    target_versions = set[ServiceVersion]()
    if summary.desired_state.HasField("service"):
        service = summary.desired_state.service
        for rc in service.release_channels:
            target_versions.add(
                ServiceVersion(
                    application=service.application,
                    service=service.service,
                    version=rc.versions[0].version,
                )
            )

    if summary.desired_state.HasField("service_group"):
        service_group = summary.desired_state.service_group
        for service in service_group.services:
            for rc in service.release_channels:
                target_versions.add(
                    ServiceVersion(
                        application=service.application,
                        service=service.service,
                        version=rc.versions[0].version,
                    )
                )

    images = set[ImageDetails]()
    for version in target_versions:
        this_images = get_images_from_service_version(
            client,
            application=version.application,
            service=version.service,
            version=version.version,
        )
        images.update(this_images)
    return images


def get_images_from_service_version(
    client: Client, application: str, service: str, version: str
) -> Set[ImageDetails]:
    resp = client.service_manager.GetMaterializedConfig(
        service_manager_pb2.GetMaterializedConfigReq(
            application=application,
            service=service,
            version=version,
        )
    )

    images = set()
    for p in resp.config.programs:
        if p.image:
            images.add(ImageDetails(image_url=p.image))
        elif p.image_tag:
            images.add(
                ImageDetails(
                    tag=TagDetails(
                        tag=p.image_tag,
                        repository=p.image_registry_info.image_repository
                        if p.image_registry_info
                        else None,
                        registry_id=p.image_registry_info.container_registry_id
                        if p.image_registry_info
                        else None,
                        registry_name=p.image_registry_info.container_registry
                        if p.image_registry_info
                        else None,
                    )
                )
            )

    for rc in resp.config.per_release_channel:
        for prc in rc.programs:
            if prc.image:
                images.add(ImageDetails(image_url=prc.image))
            elif prc.image_tag:
                images.add(
                    ImageDetails(
                        tag=TagDetails(
                            tag=prc.image_tag,
                            repository=prc.image_registry_info.image_repository
                            if prc.image_registry_info
                            else None,
                            registry_id=prc.image_registry_info.container_registry_id
                            if prc.image_registry_info
                            else None,
                            registry_name=prc.image_registry_info.container_registry
                            if prc.image_registry_info
                            else None,
                        )
                    )
                )
    return images



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/environment/environment_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.environment import clusters_pb2 as prodvana_dot_environment_dot_clusters__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.prodvana/environment/environment_manager.proto\x12\x14prodvana.environment\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a#prodvana/environment/clusters.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"3\n\x1aGetClusterAgentApiTokenReq\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"0\n\x1bGetClusterAgentApiTokenResp\x12\x11\n\tapi_token\x18\x01 \x01(\t\"\xde\x02\n\x0eLinkClusterReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04\x61uth\x18\x02 \x01(\x0b\x32!.prodvana.environment.ClusterAuth\x12/\n\x04type\x18\x06 \x01(\x0e\x32!.prodvana.environment.ClusterType\x12\x33\n\x06\x63onfig\x18\t \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12(\n\x06source\x18\x07 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x08 \x01(\x0b\x32 .prodvana.version.SourceMetadataJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06R\x10prodvana_managedR\rdisable_istioR\x0f\x64isable_flagger\"\xa8\x01\n\x0fLinkClusterResp\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x15\n\rk8s_agent_url\x18\x04 \x01(\t\x12\x17\n\x0fk8s_agent_image\x18\x05 \x01(\t\x12\x16\n\x0ek8s_agent_args\x18\x06 \x03(\t\x12\x1b\n\x13k8s_agent_api_token\x18\x07 \x01(\t\" \n\x10RemoveClusterReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x13\n\x11RemoveClusterResp\"\'\n\x11GetClusterAuthReq\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"E\n\x12GetClusterAuthResp\x12/\n\x04\x61uth\x18\x01 \x01(\x0b\x32!.prodvana.environment.ClusterAuth\"\x11\n\x0fListClustersReq\"\xab\x04\n\x10ListClustersResp\x12\x44\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x32.prodvana.environment.ListClustersResp.ClusterInfo\x1a\xd0\x03\n\x0b\x43lusterInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x04 \x01(\t\x12\x17\n\x0fservice_account\x18\x05 \x01(\t\x12/\n\x04type\x18\x07 \x01(\x0e\x32!.prodvana.environment.ClusterType\x12I\n\x03\x65\x63s\x18\x08 \x01(\x0b\x32:.prodvana.environment.ListClustersResp.ClusterInfo.EcsInfoH\x00\x12<\n\x18last_heartbeat_timestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x06\x63onfig\x18\n \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12/\n\x04\x61uth\x18\x0b \x01(\x0b\x32!.prodvana.environment.ClusterAuth\x1a.\n\x07\x45\x63sInfo\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x13\n\x0b\x63luster_arn\x18\x02 \x01(\tB\x06\n\x04infoJ\x04\x08\x03\x10\x04J\x04\x08\x06\x10\x07R\x06originR\x10writeback_config\"6\n\rGetClusterReq\x12\x0f\n\x07runtime\x18\x01 \x01(\t\x12\x14\n\x0cinclude_auth\x18\x02 \x01(\x08\"U\n\x0eGetClusterResp\x12\x43\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x32.prodvana.environment.ListClustersResp.ClusterInfo\"\xc5\x01\n\x13\x43onfigureClusterReq\x12\x14\n\x0cruntime_name\x18\x01 \x01(\t\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"\x16\n\x14\x43onfigureClusterResp\"\x97\x01\n\x1cValidateConfigureClusterResp\x12\x39\n\x0cinput_config\x18\x01 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12<\n\x0f\x63ompiled_config\x18\x02 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\"+\n\x13GetClusterConfigReq\x12\x14\n\x0cruntime_name\x18\x01 \x01(\t\"K\n\x14GetClusterConfigResp\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\".\n\x16\x44\x65tectClusterConfigReq\x12\x14\n\x0cruntime_name\x18\x01 \x01(\t\"N\n\x17\x44\x65tectClusterConfigResp\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\")\n\x13GetClusterStatusReq\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"T\n\x14GetClusterStatusResp\x12<\n\x18last_heartbeat_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\"\n\x0fPauseClusterReq\x12\x0f\n\x07runtime\x18\x01 \x01(\t\"\x12\n\x10PauseClusterResp\"#\n\x10ResumeClusterReq\x12\x0f\n\x07runtime\x18\x01 \x01(\t\"\x13\n\x11ResumeClusterResp2\xc4\x0e\n\x12\x45nvironmentManager\x12\xa3\x01\n\x17GetClusterAgentApiToken\x12\x30.prodvana.environment.GetClusterAgentApiTokenReq\x1a\x31.prodvana.environment.GetClusterAgentApiTokenResp\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/clusters/{name=*}/token\x12x\n\x0bLinkCluster\x12$.prodvana.environment.LinkClusterReq\x1a%.prodvana.environment.LinkClusterResp\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/clusters/link:\x01*\x12x\n\x0cListClusters\x12%.prodvana.environment.ListClustersReq\x1a&.prodvana.environment.ListClustersResp\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/clusters/list\x12}\n\nGetCluster\x12#.prodvana.environment.GetClusterReq\x1a$.prodvana.environment.GetClusterResp\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/clusters/{runtime=*}/get\x12\x80\x01\n\rRemoveCluster\x12&.prodvana.environment.RemoveClusterReq\x1a\'.prodvana.environment.RemoveClusterResp\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/clusters/remove:\x01*\x12\x82\x01\n\x0eGetClusterAuth\x12\'.prodvana.environment.GetClusterAuthReq\x1a(.prodvana.environment.GetClusterAuthResp\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/clusters/get_auth\x12\x9a\x01\n\x10GetClusterConfig\x12).prodvana.environment.GetClusterConfigReq\x1a*.prodvana.environment.GetClusterConfigResp\"/\x82\xd3\xe4\x93\x02)\"$/v1/clusters/{runtime_name=*}/config:\x01*\x12\xaa\x01\n\x13\x44\x65tectClusterConfig\x12,.prodvana.environment.DetectClusterConfigReq\x1a-.prodvana.environment.DetectClusterConfigResp\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/clusters/{runtime_name=*}/detect-config:\x01*\x12\x8c\x01\n\x10\x43onfigureCluster\x12).prodvana.environment.ConfigureClusterReq\x1a*.prodvana.environment.ConfigureClusterResp\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v1/clusters/configure:\x01*\x12\xa5\x01\n\x18ValidateConfigureCluster\x12).prodvana.environment.ConfigureClusterReq\x1a\x32.prodvana.environment.ValidateConfigureClusterResp\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/clusters/configure/validate:\x01*\x12\x8a\x01\n\x10GetClusterStatus\x12).prodvana.environment.GetClusterStatusReq\x1a*.prodvana.environment.GetClusterStatusResp\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/clusters/get_status\x12|\n\x0cPauseCluster\x12%.prodvana.environment.PauseClusterReq\x1a&.prodvana.environment.PauseClusterResp\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/clusters/pause:\x01*\x12\x80\x01\n\rResumeCluster\x12&.prodvana.environment.ResumeClusterReq\x1a\'.prodvana.environment.ResumeClusterResp\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/clusters/resume:\x01*BPZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environmentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.environment.environment_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environment'
  _GETCLUSTERAGENTAPITOKENREQ.fields_by_name['name']._options = None
  _GETCLUSTERAGENTAPITOKENREQ.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterAgentApiToken']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterAgentApiToken']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/clusters/{name=*}/token'
  _ENVIRONMENTMANAGER.methods_by_name['LinkCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['LinkCluster']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/clusters/link:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['ListClusters']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['ListClusters']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/clusters/list'
  _ENVIRONMENTMANAGER.methods_by_name['GetCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetCluster']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/clusters/{runtime=*}/get'
  _ENVIRONMENTMANAGER.methods_by_name['RemoveCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['RemoveCluster']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/clusters/remove:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterAuth']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterAuth']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/clusters/get_auth'
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterConfig']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterConfig']._serialized_options = b'\202\323\344\223\002)\"$/v1/clusters/{runtime_name=*}/config:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['DetectClusterConfig']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['DetectClusterConfig']._serialized_options = b'\202\323\344\223\0020\"+/v1/clusters/{runtime_name=*}/detect-config:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['ConfigureCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['ConfigureCluster']._serialized_options = b'\202\323\344\223\002\033\"\026/v1/clusters/configure:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['ValidateConfigureCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['ValidateConfigureCluster']._serialized_options = b'\202\323\344\223\002$\"\037/v1/clusters/configure/validate:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterStatus']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterStatus']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/clusters/get_status'
  _ENVIRONMENTMANAGER.methods_by_name['PauseCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['PauseCluster']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/clusters/pause:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['ResumeCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['ResumeCluster']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/clusters/resume:\001*'
  _globals['_GETCLUSTERAGENTAPITOKENREQ']._serialized_start=237
  _globals['_GETCLUSTERAGENTAPITOKENREQ']._serialized_end=288
  _globals['_GETCLUSTERAGENTAPITOKENRESP']._serialized_start=290
  _globals['_GETCLUSTERAGENTAPITOKENRESP']._serialized_end=338
  _globals['_LINKCLUSTERREQ']._serialized_start=341
  _globals['_LINKCLUSTERREQ']._serialized_end=691
  _globals['_LINKCLUSTERRESP']._serialized_start=694
  _globals['_LINKCLUSTERRESP']._serialized_end=862
  _globals['_REMOVECLUSTERREQ']._serialized_start=864
  _globals['_REMOVECLUSTERREQ']._serialized_end=896
  _globals['_REMOVECLUSTERRESP']._serialized_start=898
  _globals['_REMOVECLUSTERRESP']._serialized_end=917
  _globals['_GETCLUSTERAUTHREQ']._serialized_start=919
  _globals['_GETCLUSTERAUTHREQ']._serialized_end=958
  _globals['_GETCLUSTERAUTHRESP']._serialized_start=960
  _globals['_GETCLUSTERAUTHRESP']._serialized_end=1029
  _globals['_LISTCLUSTERSREQ']._serialized_start=1031
  _globals['_LISTCLUSTERSREQ']._serialized_end=1048
  _globals['_LISTCLUSTERSRESP']._serialized_start=1051
  _globals['_LISTCLUSTERSRESP']._serialized_end=1606
  _globals['_LISTCLUSTERSRESP_CLUSTERINFO']._serialized_start=1142
  _globals['_LISTCLUSTERSRESP_CLUSTERINFO']._serialized_end=1606
  _globals['_LISTCLUSTERSRESP_CLUSTERINFO_ECSINFO']._serialized_start=1514
  _globals['_LISTCLUSTERSRESP_CLUSTERINFO_ECSINFO']._serialized_end=1560
  _globals['_GETCLUSTERREQ']._serialized_start=1608
  _globals['_GETCLUSTERREQ']._serialized_end=1662
  _globals['_GETCLUSTERRESP']._serialized_start=1664
  _globals['_GETCLUSTERRESP']._serialized_end=1749
  _globals['_CONFIGURECLUSTERREQ']._serialized_start=1752
  _globals['_CONFIGURECLUSTERREQ']._serialized_end=1949
  _globals['_CONFIGURECLUSTERRESP']._serialized_start=1951
  _globals['_CONFIGURECLUSTERRESP']._serialized_end=1973
  _globals['_VALIDATECONFIGURECLUSTERRESP']._serialized_start=1976
  _globals['_VALIDATECONFIGURECLUSTERRESP']._serialized_end=2127
  _globals['_GETCLUSTERCONFIGREQ']._serialized_start=2129
  _globals['_GETCLUSTERCONFIGREQ']._serialized_end=2172
  _globals['_GETCLUSTERCONFIGRESP']._serialized_start=2174
  _globals['_GETCLUSTERCONFIGRESP']._serialized_end=2249
  _globals['_DETECTCLUSTERCONFIGREQ']._serialized_start=2251
  _globals['_DETECTCLUSTERCONFIGREQ']._serialized_end=2297
  _globals['_DETECTCLUSTERCONFIGRESP']._serialized_start=2299
  _globals['_DETECTCLUSTERCONFIGRESP']._serialized_end=2377
  _globals['_GETCLUSTERSTATUSREQ']._serialized_start=2379
  _globals['_GETCLUSTERSTATUSREQ']._serialized_end=2420
  _globals['_GETCLUSTERSTATUSRESP']._serialized_start=2422
  _globals['_GETCLUSTERSTATUSRESP']._serialized_end=2506
  _globals['_PAUSECLUSTERREQ']._serialized_start=2508
  _globals['_PAUSECLUSTERREQ']._serialized_end=2542
  _globals['_PAUSECLUSTERRESP']._serialized_start=2544
  _globals['_PAUSECLUSTERRESP']._serialized_end=2562
  _globals['_RESUMECLUSTERREQ']._serialized_start=2564
  _globals['_RESUMECLUSTERREQ']._serialized_end=2599
  _globals['_RESUMECLUSTERRESP']._serialized_start=2601
  _globals['_RESUMECLUSTERRESP']._serialized_end=2620
  _globals['_ENVIRONMENTMANAGER']._serialized_start=2623
  _globals['_ENVIRONMENTMANAGER']._serialized_end=4483
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/workflow/integration_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*prodvana/workflow/integration_config.proto\x12\x11prodvana.workflow\x1a\x17validate/validate.proto\"w\n\x0e\x41lertingConfig\x12>\n\tpagerduty\x18\x01 \x01(\x0b\x32+.prodvana.workflow.AlertingConfig.PagerDuty\x1a%\n\tPagerDuty\x12\x18\n\x07service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x92\x01\n\x11\x41nnotationsConfig\x12\x41\n\thoneycomb\x18\x01 \x01(\x0b\x32..prodvana.workflow.AnnotationsConfig.Honeycomb\x1a:\n\tHoneycomb\x12\x1c\n\x0b\x65nvironment\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07\x64\x61taset\x18\x02 \x01(\t\"E\n\x0bTokenConfig\x12\x18\n\x10token_secret_key\x18\x01 \x01(\t\x12\x1c\n\x14token_secret_version\x18\x02 \x01(\t\"\xa2\x01\n\x11IntegrationConfig\x12\x36\n\x0cslack_config\x18\x01 \x01(\x0b\x32\x1e.prodvana.workflow.TokenConfigH\x00\x12:\n\x10pagerduty_config\x18\x02 \x01(\x0b\x32\x1e.prodvana.workflow.TokenConfigH\x00\x42\x13\n\x0c\x63onfig_oneof\x12\x03\xf8\x42\x01J\x04\x08\x03\x10\x04\x42MZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/workflowb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.workflow.integration_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/workflow'
  _ALERTINGCONFIG_PAGERDUTY.fields_by_name['service']._options = None
  _ALERTINGCONFIG_PAGERDUTY.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _ANNOTATIONSCONFIG_HONEYCOMB.fields_by_name['environment']._options = None
  _ANNOTATIONSCONFIG_HONEYCOMB.fields_by_name['environment']._serialized_options = b'\372B\004r\002\020\001'
  _INTEGRATIONCONFIG.oneofs_by_name['config_oneof']._options = None
  _INTEGRATIONCONFIG.oneofs_by_name['config_oneof']._serialized_options = b'\370B\001'
  _globals['_ALERTINGCONFIG']._serialized_start=90
  _globals['_ALERTINGCONFIG']._serialized_end=209
  _globals['_ALERTINGCONFIG_PAGERDUTY']._serialized_start=172
  _globals['_ALERTINGCONFIG_PAGERDUTY']._serialized_end=209
  _globals['_ANNOTATIONSCONFIG']._serialized_start=212
  _globals['_ANNOTATIONSCONFIG']._serialized_end=358
  _globals['_ANNOTATIONSCONFIG_HONEYCOMB']._serialized_start=300
  _globals['_ANNOTATIONSCONFIG_HONEYCOMB']._serialized_end=358
  _globals['_TOKENCONFIG']._serialized_start=360
  _globals['_TOKENCONFIG']._serialized_end=429
  _globals['_INTEGRATIONCONFIG']._serialized_start=432
  _globals['_INTEGRATIONCONFIG']._serialized_end=594
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/labels/labels.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cprodvana/labels/labels.proto\x12\x0fprodvana.labels\x1a\x17validate/validate.proto\"k\n\x0fLabelDefinition\x12,\n\x05label\x18\x01 \x01(\tB\x1d\xfa\x42\x1ar\x18\x10\x01\x32\x14^[a-zA-Z0-9.\\-_@+]*$\x12*\n\x05value\x18\x02 \x01(\tB\x1b\xfa\x42\x18r\x16\x32\x14^[a-zA-Z0-9.\\-_@+]*$BKZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/labelsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.labels.labels_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/labels'
  _LABELDEFINITION.fields_by_name['label']._options = None
  _LABELDEFINITION.fields_by_name['label']._serialized_options = b'\372B\032r\030\020\0012\024^[a-zA-Z0-9.\\-_@+]*$'
  _LABELDEFINITION.fields_by_name['value']._options = None
  _LABELDEFINITION.fields_by_name['value']._serialized_options = b'\372B\030r\0262\024^[a-zA-Z0-9.\\-_@+]*$'
  _globals['_LABELDEFINITION']._serialized_start=74
  _globals['_LABELDEFINITION']._serialized_end=181
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import grpc
import prodvana.proto.prodvana.release.manager_pb2

class ReleaseManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    RecordRelease: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.release.manager_pb2.RecordReleaseReq,
        prodvana.proto.prodvana.release.manager_pb2.RecordReleaseResp,
    ]
    UpdateReleaseStatus: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.release.manager_pb2.UpdateReleaseStatusReq,
        prodvana.proto.prodvana.release.manager_pb2.UpdateReleaseStatusResp,
    ]
    ListReleases: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.release.manager_pb2.ListReleasesReq,
        prodvana.proto.prodvana.release.manager_pb2.ListReleasesResp,
    ]
    ListReleasesStream: grpc.UnaryStreamMultiCallable[
        prodvana.proto.prodvana.release.manager_pb2.ListReleasesReq,
        prodvana.proto.prodvana.release.manager_pb2.ListReleasesResp,
    ]
    """page tokens arguments are ignored here"""

class ReleaseManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def RecordRelease(
        self,
        request: prodvana.proto.prodvana.release.manager_pb2.RecordReleaseReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.release.manager_pb2.RecordReleaseResp: ...
    @abc.abstractmethod
    def UpdateReleaseStatus(
        self,
        request: prodvana.proto.prodvana.release.manager_pb2.UpdateReleaseStatusReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.release.manager_pb2.UpdateReleaseStatusResp: ...
    @abc.abstractmethod
    def ListReleases(
        self,
        request: prodvana.proto.prodvana.release.manager_pb2.ListReleasesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.release.manager_pb2.ListReleasesResp: ...
    @abc.abstractmethod
    def ListReleasesStream(
        self,
        request: prodvana.proto.prodvana.release.manager_pb2.ListReleasesReq,
        context: grpc.ServicerContext,
    ) -> collections.abc.Iterator[prodvana.proto.prodvana.release.manager_pb2.ListReleasesResp]:
        """page tokens arguments are ignored here"""

def add_ReleaseManagerServicer_to_server(servicer: ReleaseManagerServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/convergence/convergence_mode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+prodvana/convergence/convergence_mode.proto\x12\x14prodvana.convergence*:\n\x0f\x43onvergenceMode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x43ONVERGE\x10\x01\x12\x0c\n\x08OBSERVER\x10\x02\x42PZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/convergenceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.convergence.convergence_mode_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/convergence'
  _globals['_CONVERGENCEMODE']._serialized_start=69
  _globals['_CONVERGENCEMODE']._serialized_end=127
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.delivery_extension.config_pb2
import prodvana.proto.prodvana.delivery_extension.object_pb2
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ConfigureDeliveryExtensionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    @property
    def delivery_extension_config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        delivery_extension_config: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delivery_extension_config", b"delivery_extension_config", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension_config", b"delivery_extension_config", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___ConfigureDeliveryExtensionReq = ConfigureDeliveryExtensionReq

class ConfigureDeliveryExtensionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    delivery_extension_id: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        delivery_extension_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension_id", b"delivery_extension_id", "version", b"version"]) -> None: ...

global___ConfigureDeliveryExtensionResp = ConfigureDeliveryExtensionResp

class ValidateConfigureDeliveryExtensionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def input_config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig: ...
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig: ...
    def __init__(
        self,
        *,
        input_config: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        compiled_config: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> None: ...

global___ValidateConfigureDeliveryExtensionResp = ValidateConfigureDeliveryExtensionResp

class ListDeliveryExtensionsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDeliveryExtensionsReq = ListDeliveryExtensionsReq

class ListDeliveryExtensionsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def delivery_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.delivery_extension.object_pb2.DeliveryExtension]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        delivery_extensions: collections.abc.Iterable[prodvana.proto.prodvana.delivery_extension.object_pb2.DeliveryExtension] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extensions", b"delivery_extensions", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDeliveryExtensionsResp = ListDeliveryExtensionsResp

class GetDeliveryExtensionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_FIELD_NUMBER: builtins.int
    delivery_extension: builtins.str
    def __init__(
        self,
        *,
        delivery_extension: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension", b"delivery_extension"]) -> None: ...

global___GetDeliveryExtensionReq = GetDeliveryExtensionReq

class GetDeliveryExtensionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_FIELD_NUMBER: builtins.int
    @property
    def delivery_extension(self) -> prodvana.proto.prodvana.delivery_extension.object_pb2.DeliveryExtension: ...
    def __init__(
        self,
        *,
        delivery_extension: prodvana.proto.prodvana.delivery_extension.object_pb2.DeliveryExtension | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delivery_extension", b"delivery_extension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension", b"delivery_extension"]) -> None: ...

global___GetDeliveryExtensionResp = GetDeliveryExtensionResp

class GetDeliveryExtensionConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    delivery_extension: builtins.str
    version: builtins.str
    """omit to get latest version"""
    def __init__(
        self,
        *,
        delivery_extension: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension", b"delivery_extension", "version", b"version"]) -> None: ...

global___GetDeliveryExtensionConfigReq = GetDeliveryExtensionConfigReq

class GetDeliveryExtensionConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def input_config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig: ...
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig: ...
    version: builtins.str
    """next tag: 4"""
    def __init__(
        self,
        *,
        input_config: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        compiled_config: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config", "version", b"version"]) -> None: ...

global___GetDeliveryExtensionConfigResp = GetDeliveryExtensionConfigResp

class GetDeliveryExtensionInstanceConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_INSTANCE_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    delivery_extension_instance_id: builtins.str
    version: builtins.str
    """omit to get latest version"""
    def __init__(
        self,
        *,
        delivery_extension_instance_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension_instance_id", b"delivery_extension_instance_id", "version", b"version"]) -> None: ...

global___GetDeliveryExtensionInstanceConfigReq = GetDeliveryExtensionInstanceConfigReq

class GetDeliveryExtensionInstanceConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.CompiledDeliveryExtensionInstanceConfig: ...
    version: builtins.str
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.delivery_extension.config_pb2.CompiledDeliveryExtensionInstanceConfig | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "version", b"version"]) -> None: ...

global___GetDeliveryExtensionInstanceConfigResp = GetDeliveryExtensionInstanceConfigResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/pvn_wrapper/output.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/pvn_wrapper/output.proto\x12\x14prodvana.pvn_wrapper\"\xd2\x01\n\x06Output\x12\x11\n\texit_code\x18\x01 \x01(\x05\x12\x12\n\nexec_error\x18\x02 \x01(\t\x12\x16\n\x0estdout_blob_id\x18\x03 \x01(\t\x12\x16\n\x0estderr_blob_id\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x1a\n\x12start_timestamp_ns\x18\x06 \x01(\x03\x12\x13\n\x0b\x64uration_ns\x18\x07 \x01(\x03\x12/\n\x05\x66iles\x18\x08 \x03(\x0b\x32 .prodvana.pvn_wrapper.OutputFile\"3\n\nOutputFile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontent_blob_id\x18\x02 \x01(\tBPZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pvn_wrapperb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.pvn_wrapper.output_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pvn_wrapper'
  _globals['_OUTPUT']._serialized_start=60
  _globals['_OUTPUT']._serialized_end=270
  _globals['_OUTPUTFILE']._serialized_start=272
  _globals['_OUTPUTFILE']._serialized_end=323
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.environment import environment_manager_pb2 as prodvana_dot_environment_dot_environment__manager__pb2


class EnvironmentManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetClusterAgentApiToken = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/GetClusterAgentApiToken',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAgentApiTokenReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAgentApiTokenResp.FromString,
                )
        self.LinkCluster = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/LinkCluster',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.LinkClusterReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.LinkClusterResp.FromString,
                )
        self.ListClusters = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/ListClusters',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.ListClustersReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.ListClustersResp.FromString,
                )
        self.GetCluster = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/GetCluster',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterResp.FromString,
                )
        self.RemoveCluster = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/RemoveCluster',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.RemoveClusterReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.RemoveClusterResp.FromString,
                )
        self.GetClusterAuth = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/GetClusterAuth',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAuthReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAuthResp.FromString,
                )
        self.GetClusterConfig = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/GetClusterConfig',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterConfigResp.FromString,
                )
        self.DetectClusterConfig = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/DetectClusterConfig',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.DetectClusterConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.DetectClusterConfigResp.FromString,
                )
        self.ConfigureCluster = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/ConfigureCluster',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.ConfigureClusterReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.ConfigureClusterResp.FromString,
                )
        self.ValidateConfigureCluster = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/ValidateConfigureCluster',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.ConfigureClusterReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.ValidateConfigureClusterResp.FromString,
                )
        self.GetClusterStatus = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/GetClusterStatus',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterStatusReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterStatusResp.FromString,
                )
        self.PauseCluster = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/PauseCluster',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.PauseClusterReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.PauseClusterResp.FromString,
                )
        self.ResumeCluster = channel.unary_unary(
                '/prodvana.environment.EnvironmentManager/ResumeCluster',
                request_serializer=prodvana_dot_environment_dot_environment__manager__pb2.ResumeClusterReq.SerializeToString,
                response_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.ResumeClusterResp.FromString,
                )


class EnvironmentManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetClusterAgentApiToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LinkCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListClusters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClusterAuth(self, request, context):
        """Deprecated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClusterConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetectClusterConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateConfigureCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClusterStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EnvironmentManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetClusterAgentApiToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClusterAgentApiToken,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAgentApiTokenReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAgentApiTokenResp.SerializeToString,
            ),
            'LinkCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.LinkCluster,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.LinkClusterReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.LinkClusterResp.SerializeToString,
            ),
            'ListClusters': grpc.unary_unary_rpc_method_handler(
                    servicer.ListClusters,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.ListClustersReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.ListClustersResp.SerializeToString,
            ),
            'GetCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCluster,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterResp.SerializeToString,
            ),
            'RemoveCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveCluster,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.RemoveClusterReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.RemoveClusterResp.SerializeToString,
            ),
            'GetClusterAuth': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClusterAuth,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAuthReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAuthResp.SerializeToString,
            ),
            'GetClusterConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClusterConfig,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterConfigReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterConfigResp.SerializeToString,
            ),
            'DetectClusterConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.DetectClusterConfig,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.DetectClusterConfigReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.DetectClusterConfigResp.SerializeToString,
            ),
            'ConfigureCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureCluster,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.ConfigureClusterReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.ConfigureClusterResp.SerializeToString,
            ),
            'ValidateConfigureCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateConfigureCluster,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.ConfigureClusterReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.ValidateConfigureClusterResp.SerializeToString,
            ),
            'GetClusterStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClusterStatus,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterStatusReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.GetClusterStatusResp.SerializeToString,
            ),
            'PauseCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseCluster,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.PauseClusterReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.PauseClusterResp.SerializeToString,
            ),
            'ResumeCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeCluster,
                    request_deserializer=prodvana_dot_environment_dot_environment__manager__pb2.ResumeClusterReq.FromString,
                    response_serializer=prodvana_dot_environment_dot_environment__manager__pb2.ResumeClusterResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.environment.EnvironmentManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EnvironmentManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetClusterAgentApiToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/GetClusterAgentApiToken',
            prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAgentApiTokenReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAgentApiTokenResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LinkCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/LinkCluster',
            prodvana_dot_environment_dot_environment__manager__pb2.LinkClusterReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.LinkClusterResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListClusters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/ListClusters',
            prodvana_dot_environment_dot_environment__manager__pb2.ListClustersReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.ListClustersResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/GetCluster',
            prodvana_dot_environment_dot_environment__manager__pb2.GetClusterReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.GetClusterResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/RemoveCluster',
            prodvana_dot_environment_dot_environment__manager__pb2.RemoveClusterReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.RemoveClusterResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetClusterAuth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/GetClusterAuth',
            prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAuthReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.GetClusterAuthResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetClusterConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/GetClusterConfig',
            prodvana_dot_environment_dot_environment__manager__pb2.GetClusterConfigReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.GetClusterConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DetectClusterConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/DetectClusterConfig',
            prodvana_dot_environment_dot_environment__manager__pb2.DetectClusterConfigReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.DetectClusterConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/ConfigureCluster',
            prodvana_dot_environment_dot_environment__manager__pb2.ConfigureClusterReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.ConfigureClusterResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateConfigureCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/ValidateConfigureCluster',
            prodvana_dot_environment_dot_environment__manager__pb2.ConfigureClusterReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.ValidateConfigureClusterResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetClusterStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/GetClusterStatus',
            prodvana_dot_environment_dot_environment__manager__pb2.GetClusterStatusReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.GetClusterStatusResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/PauseCluster',
            prodvana_dot_environment_dot_environment__manager__pb2.PauseClusterReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.PauseClusterResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.environment.EnvironmentManager/ResumeCluster',
            prodvana_dot_environment_dot_environment__manager__pb2.ResumeClusterReq.SerializeToString,
            prodvana_dot_environment_dot_environment__manager__pb2.ResumeClusterResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class EnvValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    RAW_SECRET_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    KUBERNETES_SECRET_FIELD_NUMBER: builtins.int
    value: builtins.str
    raw_secret: builtins.str
    """Raw secret value to be used for user-editable YAML and RPC calls."""
    @property
    def secret(self) -> global___Secret:
        """Externally stored secret."""
    @property
    def kubernetes_secret(self) -> global___KubernetesSecret:
        """Kubernetes secret, only works for Kubernetes runtimes."""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
        raw_secret: builtins.str = ...,
        secret: global___Secret | None = ...,
        kubernetes_secret: global___KubernetesSecret | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kubernetes_secret", b"kubernetes_secret", "raw_secret", b"raw_secret", "secret", b"secret", "value", b"value", "value_oneof", b"value_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kubernetes_secret", b"kubernetes_secret", "raw_secret", b"raw_secret", "secret", b"secret", "value", b"value", "value_oneof", b"value_oneof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value_oneof", b"value_oneof"]) -> typing_extensions.Literal["value", "raw_secret", "secret", "kubernetes_secret"] | None: ...

global___EnvValue = EnvValue

class Secret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    key: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "version", b"version"]) -> None: ...

global___Secret = Secret

class KubernetesSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_NAME_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    secret_name: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        secret_name: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "secret_name", b"secret_name"]) -> None: ...

global___KubernetesSecret = KubernetesSecret



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.events import events_manager_pb2 as prodvana_dot_events_dot_events__manager__pb2


class EventsManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetEvents = channel.unary_unary(
                '/prodvana.events.EventsManager/GetEvents',
                request_serializer=prodvana_dot_events_dot_events__manager__pb2.GetEventsReq.SerializeToString,
                response_deserializer=prodvana_dot_events_dot_events__manager__pb2.GetEventsResp.FromString,
                )


class EventsManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetEvents(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventsManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEvents,
                    request_deserializer=prodvana_dot_events_dot_events__manager__pb2.GetEventsReq.FromString,
                    response_serializer=prodvana_dot_events_dot_events__manager__pb2.GetEventsResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.events.EventsManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EventsManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.events.EventsManager/GetEvents',
            prodvana_dot_events_dot_events__manager__pb2.GetEventsReq.SerializeToString,
            prodvana_dot_events_dot_events__manager__pb2.GetEventsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
